# aiida-tools

This package contains tools that make it easier to create calculations and workflows with AiiDA.

Documentation: https://aiida-tools.readthedocs.io

[![Documentation Status](https://readthedocs.org/projects/aiida-tools/badge/?version=latest)](https://aiida-tools.readthedocs.io/en/latest/?badge=latest)
